# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-05-23 17:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0008_availability'),
    ]

    operations = [
        migrations.AddField(
            model_name='lead',
            name='date',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Date'),
        ),
    ]
