# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-06-20 18:52
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0011_simpleaddress'),
    ]

    operations = [
        migrations.AddField(
            model_name='simpleaddress',
            name='supplement',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
