# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-06-13 18:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0010_merge_20170609_1453'),
    ]

    operations = [
        migrations.CreateModel(
            name='SimpleAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('street', models.CharField(blank=True, max_length=300, null=True)),
                ('number', models.CharField(blank=True, max_length=10, null=True)),
                ('neighbourhood', models.CharField(blank=True, max_length=100, null=True)),
                ('city', models.CharField(blank=True, max_length=100, null=True)),
                ('state', models.CharField(blank=True, max_length=100, null=True)),
                ('zipcode', models.CharField(blank=True, max_length=20, null=True)),
                ('country', models.CharField(blank=True, max_length=100, null=True)),
            ],
        ),
    ]
